@@ -389,9 +389,9 @@ lav2stan <- function(model, lavdata = NULL, dp = NULL, n.chains = 1, mcmcextra =
     TXT <- paste0(TXT, t1, etaname, " ~ ")
 
     if(miss.psi){
-      TXT <- paste0(TXT, "sem_lv_missing_lpdf(")
+      TXT <- paste0(TXT, "sem_lv_missing(")
     } else {
-      TXT <- paste0(TXT, "sem_lv_lpdf(")
+      TXT <- paste0(TXT, "sem_lv(")
     }
 
     TXT <- paste0(TXT, "alpha, ", betaname, ", ", psiname, ", ")
@@ -1176,7 +1176,7 @@ coeffun_stan <- function(lavpartable, pxpartable, rsob, fun = "mean") {
     ## vcorr
     draw_mat <- as.matrix(rsob)
     cmatch <- match(ptnames[pxpartable$free > 0][order(pxpartable$free[pxpartable$free > 0])], colnames(draw_mat))
-    vcorr <- cor(draw_mat[,cmatch])
+    vcorr <- cor(draw_mat[, cmatch, drop=FALSE])
 
     svmatch <- match(colnames(vcorr), names(sdvec), nomatch = 0)
     sdvec <- sdvec[svmatch]
